spoon.spoon

Package spoon :: Module spoon |
[show private | hide private]
[frames | no frames]

## Module spoon.spoon

Classes
`StringIOWrap` | Stupid wrapper around StringIO because it isn't a new style class.

Function Summary
| `decode_dict(fd, tag)`
| ``decode_lazydict`(fd, tag)` Decoding a lazy dict will just result in returning the entire object as a string.
| `decode_pyobj(fd, tag)`
| `decode_pyobj_ref(fd, tag)`
| `decode_pyobjz(fd, tag)`
| `decode_stringio(fd, tag)`
| `encode_dict(fd, item)`
| `encode_lazydict(fd, item)`
| `encode_pyobj(fd, obj, omittag)`
| `encode_pyobjz(fd, obj)`
| `encode_stringio(fd, item)`

Variable Summary
`Tag` | `DICT_TAG` = `<ASN.1 Tag(APPLICATION, 1, size=None, contain...`
`Tag` | `LAZY_DICT_TAG` = `<ASN.1 Tag(APPLICATION, 4, size=None, co...`
`Tag` | `PYOBJ_REF_TAG` = `<ASN.1 Tag(APPLICATION, 3, size=None, co...`
`Tag` | `PYOBJ_TAG` = `<ASN.1 Tag(APPLICATION, 2, size=None, contai...`
`Tag` | `PYOBJZ_TAG` = `<ASN.1 Tag(APPLICATION, 6, size=None, conta...`
`Tag` | `SPOONLINKMSG_TAG` = `<ASN.1 Tag(APPLICATION, 7, size=None,...`
`Tag` | `SPOONNETMSG_TAG` = `<ASN.1 Tag(APPLICATION, 8, size=None, ...`
`Tag` | `STRING_BUFF_TAG` = `<ASN.1 Tag(APPLICATION, 5, size=None, ...`

Function Details

### decode_lazydict(fd, tag) Decoding a lazy dict will just result in returning the entire object as a string.

Variable Details

    ### DICT_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 1, size=None, container=True)>

    ### LAZY_DICT_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 4, size=None, container=True)>

    ### PYOBJ_REF_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 3, size=None, container=False)>

    ### PYOBJ_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 2, size=None, container=True)>

    ### PYOBJZ_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 6, size=None, container=False)>

    ### SPOONLINKMSG_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 7, size=None, container=True)>

    ### SPOONNETMSG_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 8, size=None, container=True)>

    ### STRING_BUFF_TAG Type: `Tag` Value:
        <ASN.1 Tag(APPLICATION, 5, size=None, container=True)>

Generated by Epydoc 2.1 on Sun Nov 26 15:33:58 2006 | http://epydoc.sf.net